@@ -1,9 +1,9 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: hakyll
-version: 4.8.3.0
-id: hakyll-4.8.3.0-64cf2972080346c1cf61367bd93b3a76
-key: hakyl_7pyFEvOWjZ80tsi5cBH26x
+version: 4.8.3.1
+id: hakyll-4.8.3.1-1c5b16d553db3c4a3f4f34c03e621c26
+key: hakyl_04pmgAtpxIg6RLyxqzmdp3
 license: BSD3
 maintainer: Jasper Van der Jeugt <m@jaspervdj.be>
 homepage: http://jaspervdj.be/hakyll
@@ -48,10 +48,10 @@ hidden-modules: Data.List.Extended Data.Yaml.Extended Hakyll.Check
                 Hakyll.Core.Runtime Hakyll.Core.Store Hakyll.Core.Util.File
                 Hakyll.Core.Util.Parser Hakyll.Web.Pandoc.Binary Paths_hakyll
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/hakyll-4.8.3.0
-library-dirs: /usr/lib/ghc-7.10.3/site-local/hakyll-4.8.3.0
-data-dir: /usr/share/arm-linux-ghc-7.10.3/hakyll-4.8.3.0
-hs-libraries: HShakyll-4.8.3.0-7pyFEvOWjZ80tsi5cBH26x
+import-dirs: /usr/lib/ghc-7.10.3/site-local/hakyll-4.8.3.1
+library-dirs: /usr/lib/ghc-7.10.3/site-local/hakyll-4.8.3.1
+data-dir: /usr/share/arm-linux-ghc-7.10.3/hakyll-4.8.3.1
+hs-libraries: HShakyll-4.8.3.1-04pmgAtpxIg6RLyxqzmdp3
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     binary-0.7.5.0-29f7044fa0b12dc5c2dcec897db5c464
@@ -65,20 +65,21 @@ depends:
     deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
     directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
     filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
-    http-conduit-2.1.10.1-06d6cae4a7dc7e652455c24a41eb9def
+    http-conduit-2.1.10.1-9bcd28b714a9db44a394bc84b9d644e0
     http-types-0.9-abc209b9e91b870b477d7ec7669b4ae8
     lrucache-1.2.0.0-f6a00c6545b50474cbf44906f698e532
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
     network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
-    network-uri-2.6.1.0-0e39aca8530572505c01ef548c540bd6
-    pandoc-1.17.0.3-45381fe983c6bd3cb90c0ba87bbc9082
-    pandoc-citeproc-0.9.1.1-5d34ad48004833484b402d29858f377a
-    parsec-3.1.9-3365ddffd9ca11d2f0b377e002b54baf
+    network-uri-2.6.1.0-522aa8cc2805dab5af7064f70c4a777d
+    pandoc-1.17.0.3-385c8e8a07c6129d5c295aa0dcb411ba
+    pandoc-citeproc-0.9.1.1-5748d0995df6dc75a64f38e63a91d870
+    parsec-3.1.11-2df9dc070a05b018377712731c5dde62
     process-1.2.3.0-21d25f1d78aeea6e68f1c768841f9794
     random-1.1-41a0a7ecd483c665a5c3a093a5be2968
     regex-base-0.93.2-42cdf19dc92d6af642a96da5984c8c2c
-    regex-tdfa-1.2.2-356f1fd0d011fc4d4ac3ea6a1e65b0ca
+    regex-tdfa-1.2.2-5c2f2dacf3d81105b689ea15cddbfda5
     resourcet-1.1.7.4-51f149abafdcf0369a30d929df00de54
+    scientific-0.3.4.6-7ee193f22b0f4a7e2e484deeaee5cd03
     tagsoup-0.13.10-e0607642a7a600be1f9d9bab46fd617e
     text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
     time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
